@@ -13,7 +13,20 @@ universal_newlines=False, startupinfo=None, creationflags=0
 """
 
 def cmdexec(cmd, timeout = 10, **kwargs):
-    """ 执行系统命令, 返回: code, stdout, stderr, 当code不为0则为报错"""
+    """
+    执行系统命令, 返回: code, stdout, stderr, 当code不为0则为报错
+
+    **Parameters:**
+
+    * **cmd:** `str` -- 命令文本
+    * **timeout:** `int` -- 超时时间
+
+    **Return:**
+
+    * **code:** `int` 为0则执行成功，否则执行失败
+    * **success:** `str` 执行成功打印内容
+    * **error:** `str` 执行失败打印内容
+    """
     logger.warning('执行命令: %s' % cmd)
     subp = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE, **kwargs)
     timer = Timer(timeout, lambda p: p.kill(), [subp])
