@@ -15,7 +15,17 @@ defaultConfig = {
 }
 
 def getConfig(name, file='config.ini', default={}):
-    '''返回能获取全局配置文件值的函数'''
+    """
+    返回能够获取全局配置文件(`$SUNDAY_ROOT/config.ini`)内配置值的函数
+
+    **Parameters:**
+
+    * **name:** `str` -- 键名
+    * **file:** `str` -- 文件名
+    * **default:** `dict` -- 默认配置的集合，优先级大于全局的配置
+
+    **Return:** `getval(key)`
+    """
     configPwd = os.path.join(paths.rootCwd, file)
     cfg = ConfigParser()
     cfg.read(configPwd, encoding='utf-8')
