@@ -6,8 +6,26 @@ from pydash.arrays import union
 class SundayError(Exception): pass
 
 def getException(errorMap={}, allowAttr=[]):
+    """
+    生成报错捕获对象，继承于CustomError > SundayError，默认存在属性code、message
+
+    **Usage:**
+
+    ```
+    >>> from sunday.core.getException import getException
+    >>> MyError = getException({ 10000: '错误提示文本' })
+    >>> raise MyError(10000)
+    ```
+
+    **Parameters:**
+
+    * **errorMap:** `dict` -- 错误映射字典，一般就是数字或字符键对应报错说明
+    * **allowAttr:** `list` -- 允许的额外属性键列表
+
+    **Return:** `NewError`
+    """
     class CustomError(SundayError):
-        def __init__(self, code=10000, message=None, other='', errorMap=errorMap, **kwargs):
+        def __init__(self, code=10001, message=None, other='', errorMap=errorMap, **kwargs):
             self.code = code
             tip = message or errorMap.get(code, '未知code: %s' % code)
             self.message = tip + ('(%s)' % other if other else '')
